function getColumnArray(columns) {
    var line = [];
    columns.forEach(function(el) {
        if (el.show) {
            if (el.label) {
                line.push(el.label);
            } else {
                line.push(el.key);
            }
        }
    });
    return line;
}

exports.downloadTable = function(columns, rows, filename) {
    var lineArray = [];
    var line = getColumnArray(columns);
    line = line.join("\t");
    lineArray.push(line);
    rows.forEach(function(row) {
        var line = [];
        for (var i = 0; i < columns.length; i++) {
            var col = columns[i];
            if (col.show) {
                let l = "";
                if (col.render) {
                    l = String(col.render(row))
                        .replace(/<\/?[^>]+(>|$)/g, "")
                        .replace(/"/g, "'");
                } else if (row[col.key]) {
                    l = String(row[col.key]).replace(/"/g, "'");
                }
                if (col.type === "number") {
                    line.push(l ? l.replace(/\./g, ",") : "");
                } else {
                    line.push('"' + l + '"');
                }
            }
        }
        line = line.join("\t");
        lineArray.push(line);
    });
    var csvContent = lineArray.join("\n");
    var csvData = new Blob([csvContent], { type: "text/tsv;charset=utf-8;" });
    //IE11 & Edge
    if (navigator.msSaveBlob) {
        navigator.msSaveBlob(csvData, filename);
    } else {
        var link = document.createElement("a");
        link.href = window.URL.createObjectURL(csvData);
        link.setAttribute("download", filename);
        document.body.appendChild(link);
        link.click();
        document.body.removeChild(link);
    }
};

exports.printTable = function(columns, rows) {
    var lineArray = "";
    var line = "<tr>";
    var cols = getColumnArray(columns);
    for (var i = 0; i < cols.length; i++) {
        line += "<td>" + cols[i] + "</td>";
    }
    line += "</tr>";
    lineArray += line;
    rows.forEach(function(row) {
        var line = "<tr>";
        for (var i = 0; i < columns.length; i++) {
            var col = columns[i];
            if (col.show) {
                if (col.render) {
                    line +=
                        "<td>" +
                        String(col.render(row))
                            .replace(/<\/?[^>]+(>|$)/g, "")
                            .replace(/"/g, "'") +
                        "</td>";
                } else if (row[col.key]) {
                    line += "<td>" + row[col.key] + "</td>";
                } else {
                    line += "<td></td>";
                }
            }
        }
        line += "</tr>";
        lineArray += line;
    });
    var inner = "<table>" + lineArray + "</table>";
    inner += "<style>th,td{padding: 1px 5px;";
    inner += "text-align: left;";
    inner += "border: 1px solid #E1E1E1;}table {";
    inner += "border-collapse: collapse;";
    inner += "}</style>";
    var frame = document.createElement("iframe");
    document.body.appendChild(frame);
    var frm = frame.contentWindow;
    frm.document.body.innerHTML = inner;
    frm.focus();
    frm.print();
    document.body.removeChild(frame);
};
